/***************************************************************************
 *                                                                         *
 *   Copyright 2019 David Redondo <kde@david-redondo.de>                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 *                                                                         *
 ***************************************************************************/

#ifndef CUTTLEFISHCOLORSCHEMES_H
#define CUTTLEFISHCOLORSCHEMES_H

#include <QObject>
#include <QString>

class QAbstractItemModel;

class KColorSchemeManager;

namespace CuttleFish {
class ColorSchemes : public QObject {

    Q_OBJECT

    Q_PROPERTY(QAbstractItemModel *colorSchemes READ  colorSchemes CONSTANT)

public:
    Q_INVOKABLE void activateColorScheme(const QString &name);

    ColorSchemes(QObject *parent);

    QAbstractItemModel* colorSchemes();

private:
    KColorSchemeManager* m_colorManager;
};
}
#endif
